%define oname     felinks

Summary:	Lynx-like text WWW browser
Name:		elinks
Version:	0.16.0
Release:        %mkrel 1
License:	GPLv2
Group:		Networking/WWW
URL:		https://github.com/rkd77/felinks
Source0:	https://github.com/rkd77/%{oname}/archive/v%{version}/%{oname}-%{version}.tar.gz
BuildRequires:	dblatex
BuildRequires:	doxygen
BuildRequires:	git-core
BuildRequires:	gpm-devel
BuildRequires:	meson
BuildRequires:	ncursesw-devel
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(expat)
BuildRequires:	pkgconfig(libevent)
BuildRequires:	pkgconfig(libidn2)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(tre)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	xmlto
Provides:	webclient
Provides:	%{oname} = %{version}-%{release}

# Prevent crash when HOME is unset (bug #90663).
Patch0: 0000-elinks-0.15.0-ssl-noegd.patch

# UTF-8 by default
Patch1: 0001-elinks-0.15.1-utf_8_io-default.patch

# Make getaddrinfo call use AI_ADDRCONFIG.
Patch3: elinks-0.11.0-getaddrinfo.patch

# Don't put so much information in the user-agent header string (bug #97273).
Patch4: 0004-elinks-0.15.0-sysname.patch

# Fix xterm terminal: "Linux" driver seems better than "VT100" (#128105)
Patch5: 0005-elinks-0.15.0-xterm.patch

# add support for GNU Libidn2, patch by Robert Scheck (#1098789)
Patch6: 0006-elinks-0.16.0-libidn2.patch

# let list_is_singleton() return false for an empty list (#1075415)
Patch15: elinks-0.12pre6-list_is_singleton.patch

%description
ELinks is an advanced and well-established feature-rich text mode web
(HTTP/FTP/..) browser. ELinks can render both frames and tables, is highly
customizable and can be extended via scripts. Its features include:

- renders tables and frames
- displays colors as specified in current HTML page
- uses drop-down menu (like in Midnight Commander)
- can download files in background
- HTTP authentication

%prep
%autosetup -p1

# remove bogus serial numbers
sed -e 's/^# *serial [AM0-9]*$//' -i config/m4/*.m4

%build
./autogen.sh
%meson \
	-D256-colors=true \
	-Dtrue-color=true \
	-Dbittorrent=true \
	-Dterminfo=true \
	-Didn2=true \
	-Dfsp=false
%meson_build

%post
update-alternatives --install %{_bindir}/links links %{_bindir}/elinks 50

%preun
if [ "$1" = "0" ]; then
  update-alternatives --remove links %{_bindir}/elinks
fi

%install
%meson_install

rm -f %{buildroot}/%{_datadir}/locale/locale.alias
rm -f doc/html/*.gz

%find_lang %{name}

%files -f %{name}.lang
%license COPYING
%doc AUTHORS BUGS ChangeLog README SITES THANKS TODO
%doc doc/*.txt
%{_bindir}/*
%{_mandir}/man?/*


%changelog
* Wed Jan 18 2023 luigiwalser <luigiwalser> 0.16.0-1.mga9
+ Revision: 1934215
- try to fix libidn2 build with meson
- 0.16.0
- build with libidn2 with patch from fedora

* Thu Nov 24 2022 ghibo <ghibo> 0.15.1-3.mga9
+ Revision: 1910721
- Merge patches from FC
- Use git-core instead of git in BRs (thanks to kekepower)

* Wed Nov 23 2022 ghibo <ghibo> 0.15.1-2.mga9
+ Revision: 1910577
- Add missed libevent to BR

* Wed Nov 23 2022 ghibo <ghibo> 0.15.1-1.mga9
+ Revision: 1910576
- Add dblatex, xmlto to BR
- Add missed git to BR
- Update to release 0.15.1.
- Switch to meson.
- Reorder BuildRequires.
- More BuildRequires.

* Fri Apr 01 2022 umeabot <umeabot> 0.14.3-2.mga9
+ Revision: 1839292
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 0.14.3-1.mga9
+ Revision: 1748490
- new version 0.14.3
- drop unneeded epoch
- rebuild for openssl 3.0.0

* Thu Nov 05 2020 wally <wally> 0:0.13.5-1.mga8
+ Revision: 1642950
- new version 0.13.5

* Tue Jun 30 2020 joequant <joequant> 0:0.13.1-2.mga8
+ Revision: 1600661
- remove arm workaround

* Fri May 22 2020 ovitters <ovitters> 0:0.13.1-1.mga8
+ Revision: 1586830
- switch to maintained elinks fork
- new version 0.13.1

* Thu Feb 13 2020 umeabot <umeabot> 0:0.12-19.mga8
+ Revision: 1512085
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 0:0.12-18.mga7
+ Revision: 1297585
- Mageia 7 Mass Rebuild

* Wed Jun 06 2018 wally <wally> 0:0.12-17.mga7
+ Revision: 1234967
- really fix build on aarch64

* Wed Jun 06 2018 wally <wally> 0:0.12-16.mga7
+ Revision: 1234963
- fix build on aarch64

* Tue May 22 2018 pterjan <pterjan> 0:0.12-15.mga7
+ Revision: 1231487
- Remove BuildRequires on unused ancient mozjs, patch to use it has been broken since it was added in 2011

* Fri May 11 2018 kekepower <kekepower> 0:0.12-14.mga7
+ Revision: 1228348
- Rebuild for libidn 1.35

* Sat May 05 2018 daviddavid <daviddavid> 0:0.12-13.mga7
+ Revision: 1226272
- rediff git-0c3f3e09 patch and openssl11 patch to fix build
+ kekepower <kekepower>
- Use new make macros

* Sat Sep 02 2017 cjw <cjw> 0:0.12-12.mga7
+ Revision: 1150935
- add a couple of patches from fedora to fix build with new openssl

* Wed Mar 02 2016 umeabot <umeabot> 0:0.12-11.mga6
+ Revision: 983389
- Rebuild for openssl

* Mon Feb 08 2016 umeabot <umeabot> 0:0.12-10.mga6
+ Revision: 944212
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0:0.12-9.mga5
+ Revision: 748520
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0:0.12-8.mga5
+ Revision: 678988
- Mageia 5 Mass Rebuild

* Sun Jan 05 2014 shlomif <shlomif> 0:0.12-7.mga4
+ Revision: 564909
- Remove trailing whitespace in .spec
- Stop providing "links" so one can install both "links" and "elinks".
  There may still be an issue with the alternatives of links being set to
  elinks, but I'll leave it for later discussion.
- New rel as apparently the pre does not affect the version
- Applied the patch for MAG #11460.
  Fix for a CVE bug for validating the SSL signatures.
  I checked the behaviour of elinks with https://github.com/ and
  https://metacpan.org/ .
- New version 0.12pre6

* Fri Oct 18 2013 umeabot <umeabot> 0:0.12-4.mga4
+ Revision: 504095
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 0:0.12-3.mga3
+ Revision: 349593
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 29 2012 luigiwalser <luigiwalser> 0:0.12-2.mga3
+ Revision: 335994
- add patch from debian to fix CVE-2012-4545

* Sat Mar 12 2011 ahmad <ahmad> 0:0.12-1.mga1
+ Revision: 70122
- update to 0.12pre5
- rediff patch0
- imported package elinks


* Wed Feb 02 2011 Funda Wang <fwang@mandriva.org> 0:0.11.7-4mdv2011.0
+ Revision: 635335
- simplify BR

* Sun Dec 05 2010 Oden Eriksson <oeriksson@mandriva.com> 0:0.11.7-3mdv2011.0
+ Revision: 610352
- rebuild

* Thu Apr 08 2010 Rémy Clouard <shikamaru@mandriva.org> 0:0.11.7-2mdv2010.1
+ Revision: 533230
- Rebuild for new openssl

* Tue Sep 15 2009 Frederik Himpe <fhimpe@mandriva.org> 0:0.11.7-1mdv2010.0
+ Revision: 443218
- update to new version 0.11.7

* Thu Sep 10 2009 Thierry Vignaud <tv@mandriva.org> 0:0.11.5-2mdv2010.0
+ Revision: 437411
- rebuild

* Sat Oct 11 2008 Frederik Himpe <fhimpe@mandriva.org> 0:0.11.5-1mdv2009.1
+ Revision: 291683
- update to new version 0.11.5

* Tue Jun 24 2008 Oden Eriksson <oeriksson@mandriva.com> 0:0.11.4-2mdv2009.0
+ Revision: 228612
- fix libjs stuff

  + Frederik Himpe <fhimpe@mandriva.org>
    - New version 0.11.4
    - New license policy

* Tue Feb 05 2008 Frederik Himpe <fhimpe@mandriva.org> 0:0.11.4-1mdv2008.1
+ Revision: 162812
- New stable version 0.11.4rc0 (fixes security problem CVE-2007-2027)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Jul 09 2007 Funda Wang <fwang@mandriva.org> 0:0.11.3-1mdv2008.0
+ Revision: 50444
- New version


* Mon Nov 20 2006 Lenny Cartier <lenny@mandriva.com> 0.11.2-1mdv2007.0
+ Revision: 85504
- Update to 0.11.2
- Import elinks

* Mon Jun 12 2006 Charles A Edwards <eslrahc@mandriva.org> 0.11.1-1mdv2007.1
- 0.11.1
- mkrel
- enable bittorrent support
- update doc listing

* Mon May 08 2006 Jerome Soyer <saispo@mandriva.org> 0.10.6-1mdk
- New release 0.10.6

* Fri Mar 24 2006 Pixel <pixel@mandriva.com> 0.10.5-3mdk
- add BuildRequires X11-devel
- rebuild (for crypto deps)

* Tue Aug 09 2005 Abel Cheung <deaddog@mandriva.org> 0:0.10.5-2mdk
- Rebuild, to get back rpms

* Tue Aug 09 2005 Abel Cheung <deaddog@mandriva.org> 0:0.10.5-1mdk
- 0.10.5
- Remove menu again
- Elinks only reads per-user config, attempt to place global config
  randomly is useless
- Take description from elinks itself
- Remove message during install, which was related to around 0.4 days
- Fix scriptlets
- Tune up alt priority, because if people pick up this non-default
  links, that means people really want to try it

* Sat Apr 09 2005 Charles A Edwards <eslrahc@mandrake.org> 0:0.10.4-1mdk
- 0.10.4

* Tue Mar 01 2005 Lenny Cartier <lenny@mandrakesoft.com> 0:0.10.3-1mdk
- 0.10.3

* Thu Feb 03 2005 Charles A Edwards <eslrahc@mandrake.org> 0:0.10.2-1mdk
- 0.10.2

* Wed Jan 05 2005 Lenny Cartier <lenny@mandrakesoft.com> 0.10.1-1mdk
- 0.10.1

* Mon Dec 27 2004 Charles A Edwards <eslrahc@mandrake.org> 0.10.0-1mdk
- 0.10.0
- put back menu entry

* Wed Aug 04 2004 Lenny Cartier <lenny@mandrakesoft.com> 0.9.2-0.rc4.1mdk
- 0.9.2rc4

* Fri Jul 23 2004 Charles A Edwards <eslrahc@mandrake.org> 0.9.2-0.rc3.1mdk
- 0.9.2rc3

* Wed Jun 30 2004 Lenny Cartier <lenny@mandrakesoft.com> 0.9.2-0.rc2.1mdk
* Tue Jun 23 2004 Charles A Edwards <eslrahc@mandrake.org> 0.9.2-0.rc1.1mdk
- 0.9.2rc1

* Mon Feb 09 2004 Abel Cheung <deaddog@deaddog.org> 0.9.1-2mdk
- Remove files provided by glibc
- BuildRequires smbclient (for smb:// support)
- Remove menu entry (people won't expect text mode browsers appear in menu)

